@@ -66,7 +66,7 @@ class Section(metaclass=StructMeta):
         for iEntry in range(self.n_entries):
             with warnings.catch_warnings():
                 warnings.simplefilter("ignore")
-                
+
                 poly_der = self._poly[iEntry].deriv(1)
                 self._poly_der.append(poly_der)
 
@@ -360,6 +360,13 @@ class TimeLine():
 
         return ax
 
+    @classmethod
+    def from_constant(cls, start, end, value):
+        tl = cls()
+        tl.add_section(Section(start, end, value))
+
+        return tl
+
 
 class MultiTimeLine():
     def __init__(self, base_state):
