@@ -1,7 +1,5 @@
-from .objectiveFunctions import *
-from .nonlinearConstraintFunctions import *
+from .progress import *
 from .optimizationProblem import *
-from .solver import *
+from .optimizer import *
 from .scipyAdapter import COBYLA, TrustConstr, NelderMead, SLSQP
-from .deapAdapter import DEAP
 from .pymooAdapter import NSGA2, U_NSGA3
