@@ -356,7 +356,7 @@ class OptimizationProblem(metaclass=StructMeta):
             return func(self, population, *args, **kwargs)
 
         return wrapper
-    
+
     @untransforms
     def get_dependent_values(self, x):
         """Determine values of dependent optimization variables.
@@ -599,7 +599,7 @@ class OptimizationProblem(metaclass=StructMeta):
             raise TypeError("Expected callable objective.")
 
         if bad_metrics is None and isinstance(objective, MetricBase):
-            bad_metrics = objective.bad_metrics
+            bad_metrics = n_objectives * objective.bad_metrics
 
         if evaluation_objects is None:
             evaluation_objects = []
@@ -1921,7 +1921,10 @@ class OptimizationProblem(metaclass=StructMeta):
                 self.lower_bounds,
                 self.upper_bounds
             )
-            problem = hopsy.round(problem)
+            try:
+                problem = hopsy.round(problem)
+            except np.linalg.LinAlgError:
+                pass
 
             chebyshev = hopsy.compute_chebyshev_center(problem)
 
