@@ -53,6 +53,13 @@ class ComponentSystem(metaclass=StructMeta):
     def components(self):
         return self._components
 
+    @property
+    def components_dict(self):
+        return {
+            name: comp
+            for name, comp in zip(self.names, self.components)
+        }
+
     @property
     def n_components(self):
         return len(self.components)
@@ -66,6 +73,18 @@ class ComponentSystem(metaclass=StructMeta):
         component = Component(*args, **kwargs)
         self._components.append(component)
 
+    def remove_component(self, component):
+        if isinstance(component, (str, int)):
+            try:
+                component = self.components_dict[component]
+            except KeyError:
+                raise CADETProcessError("Unknown Component.")
+
+        if component not in self.components:
+            raise CADETProcessError("Unknown Component.")
+
+        self._components.remove(component)
+
     @property
     def indices(self):
         indices = defaultdict(list)
