@@ -45,13 +45,19 @@ class DiscretizationParametersBase(ParametersGroup):
         except KeyError:
             pass
 
-        super(DiscretizationParametersBase, self.__class__).parameters.fset(self, parameters)
+        super(DiscretizationParametersBase, self.__class__).parameters.fset(
+            self, parameters
+        )
 
 
 class NoDiscretization(DiscretizationParametersBase):
     pass
 
 
+class DGMixin():
+    pass
+
+
 class LRMDiscretizationFV(DiscretizationParametersBase):
     ncol = UnsignedInteger(default=100)
     use_analytic_jacobian = Bool(default=True)
@@ -63,6 +69,25 @@ class LRMDiscretizationFV(DiscretizationParametersBase):
     _dimensionality = ['ncol']
 
 
+class LRMDiscretizationDG(DiscretizationParametersBase, DGMixin):
+    ncol = UnsignedInteger(default=16)
+    use_analytic_jacobian = Bool(default=True)
+    reconstruction = Switch(default='WENO', valid=['WENO'])
+    polynomial_degree = UnsignedInteger(default=3)
+    polydeg = polynomial_degree
+    polynomial_basis = Switch(valid=['LAGRANGE', 'JACOBI'], default='LAGRANGE')
+
+    _parameters = DiscretizationParametersBase._parameters + [
+        'ncol', 'use_analytic_jacobian', 'reconstruction',
+        'polydeg', 'polynomial_basis'
+    ]
+    _dimensionality = ['axial_dof']
+
+    @property
+    def axial_dof(self):
+        return self.ncol * (self.polynomial_degree + 1)
+
+
 class LRMPDiscretizationFV(DiscretizationParametersBase):
     ncol = UnsignedInteger(default=100)
 
