@@ -33,6 +33,9 @@ from CADETProcess.dataStructure import (
 from CADETProcess.processModel import ComponentSystem
 from CADETProcess import plotting
 
+from CADETProcess import smoothing
+from CADETProcess import transform
+
 
 class SolutionBase(metaclass=StructMeta):
     name = String()
@@ -121,6 +124,23 @@ class SolutionIO(SolutionBase):
         self.solution = solution
         self.flow_rate = flow_rate
 
+        self.time_original = time
+        self.solution_original = solution
+
+        self.is_resampled = False
+
+        self.s = None
+        self.crit_fs = None
+        self.crit_fs_der = None
+        self.is_smoothed = False
+
+        self.is_normalized = False
+
+        self.update()
+
+    def reset(self):
+        self.time = self.time_original
+        self.solution = self.solution_original
         self.update()
 
     def update(self):
@@ -129,22 +149,135 @@ class SolutionIO(SolutionBase):
         q_vector = vec_q_value(self.time)
         dm_dt = self.solution * q_vector[:, None]
 
+        self.transform = transform.NormLinearTransform(
+            np.min(self.solution, axis=0), np.max(self.solution, axis=0)
+        )
+
         self.interpolated_dm_dt = InterpolatedSignal(self.time, dm_dt)
         self.interpolated_Q = InterpolatedUnivariateSpline(self.time, q_vector)
 
+    def normalize(self):
+        if self.is_normalized:
+            return
+
+        self.solution = self.transform.transform(self.solution)
+        self.is_normalized = True
+
+    def denormalize(self):
+        if not self.is_normalized:
+            return
+
+        self.solution = self.transform.untransform(self.solution)
+        self.is_normalized = False
+
     def resample(self, nt=5001):
         """Resample solution to nt time points.
 
         Parameters
         ----------
         nt : int, optional
-            Number of points to resample. The default is 5000.
+            Number of points to resample. The default is 5001.
 
         """
+        if self.is_resampled:
+            return
+
         self.time = np.linspace(self.time[0], self.time[-1], nt)
         self.solution = self.solution_interpolated(self.time)
 
-    def fraction_mass(self, start, end):
+        self.update()
+
+        self.is_resampled = True
+
+    def smooth_data(self, s=None, crit_fs=None, crit_fs_der=None):
+        """Smooth data.
+
+        Parameters
+        ----------
+        s : float or list, optional
+            DESCRIPTION. The default is 0.
+        crit_fs : float or list
+            DESCRIPTION.
+        crit_fs_der : float or list
+            DESCRIPTION.
+
+        """
+        if self.is_smoothed:
+            return
+
+        if not self.is_resampled:
+            self.resample()
+
+        if not self.is_normalized:
+            normalized = True
+            self.normalize()
+        else:
+            normalized = False
+
+        if s is None:
+            self.s = []
+            self.crit_fs = []
+            self.crit_fs_der = []
+
+            for i in range(self.n_comp):
+                s, crit_fs, crit_fs_der = smoothing.find_smoothing_factors(
+                    self.time, self.solution[..., i]
+                )
+                self.s.append(s)
+                self.crit_fs.append(crit_fs)
+                self.crit_fs_der.append(crit_fs_der)
+
+            s = self.s
+            crit_fs = self.crit_fs
+            crit_fs_der = self.crit_fs_der
+
+        if np.isscalar(s):
+            s = self.n_comp * [s]
+        if np.isscalar(crit_fs):
+            crit_fs = self.n_comp * [crit_fs]
+        if np.isscalar(crit_fs_der):
+            crit_fs_der = self.n_comp * [crit_fs_der]
+
+        solution = np.zeros((self.solution.shape))
+        for i, (s, crit_fs, crit_fs_der) in enumerate(zip(s, crit_fs, crit_fs_der)):
+            smooth, smooth_der = smoothing.full_smooth(
+                self.time, self.solution[..., i],
+                crit_fs, s, crit_fs_der
+            )
+            solution[..., i] = smooth
+
+        self.solution = solution
+
+        if normalized:
+            self.denormalize()
+
+        self.update()
+
+        self.is_smoothed = True
+
+    def integral(self, start=0, end=None):
+        """Peak area in a fraction interval.
+
+        Parameters
+        ----------
+        start : float
+            Start time of the fraction
+
+        end: float
+            End time of the fraction
+
+        Returns
+        -------
+        Area : np.array
+            Mass of all components in the fraction
+
+        """
+        if end is None:
+            end = self.cycle_time
+
+        return self.solution_interpolated.integral(start, end)
+
+    def fraction_mass(self, start=0, end=None):
         """Component mass in a fraction interval
 
         Parameters
@@ -161,9 +294,12 @@ class SolutionIO(SolutionBase):
             Mass of all components in the fraction
 
         """
+        if end is None:
+            end = self.cycle_time
+
         return self.interpolated_dm_dt.integral(start, end)
 
-    def fraction_volume(self, start, end):
+    def fraction_volume(self, start=0, end=None):
         """Volume of a fraction interval
 
         Parameters
@@ -180,6 +316,9 @@ class SolutionIO(SolutionBase):
             Volume of the fraction
 
         """
+        if end is None:
+            end = self.cycle_time
+
         return self.interpolated_Q.integral(start, end)
 
     @plotting.create_and_save_figure
@@ -982,7 +1121,7 @@ class InterpolatedSignal():
 
         return der
 
-    def integral(self, start, end):
+    def integral(self, start=0, end=-1):
         """Definite integral between start and end.
 
         Parameters
