@@ -7,14 +7,14 @@ Todo
 
 
 - event times (especially considerung time modulo cycle time)
-- event /parameter/ performer timelines 
+- event /parameter/ performer timelines
 - section states (especially piecewise poly times)
 
 - conflicing events at same time?
 
 Notes
 -----
-    Since the EventHandler defines an interface, that requires the 
+    Since the EventHandler defines an interface, that requires the
     implementation of some methods, a TestHandler class is defined.
 
 Maybe this is too complicated, just use Process instead?
@@ -23,17 +23,17 @@ Maybe this is too complicated, just use Process instead?
 import unittest
 
 from addict import Dict
-import numpy as np
 
 import CADETProcess
 from CADETProcess import CADETProcessError
 from CADETProcess.dataStructure import StructMeta
 from CADETProcess.dataStructure import Float, Switch, SizedTuple
 
+
 class TestPerformer(metaclass=StructMeta):
     param_1 = Float(default=0)
-    param_2 = SizedTuple(minlen=2, maxlen=2, default=(1,1))
-    param_3 = Switch(valid=[-1,1], default=1)
+    param_2 = SizedTuple(minlen=2, maxlen=2, default=(1, 1))
+    param_3 = Switch(valid=[-1, 1], default=1)
 
     _parameters = ['param_1', 'param_2', 'param_3']
     _section_dependent_parameters = ['param_1', 'param_2']
@@ -41,7 +41,7 @@ class TestPerformer(metaclass=StructMeta):
     @property
     def section_dependent_parameters(self):
         parameters = {
-            param: getattr(self, param) 
+            param: getattr(self, param)
             for param in self._section_dependent_parameters
         }
         return parameters
@@ -49,11 +49,11 @@ class TestPerformer(metaclass=StructMeta):
     @property
     def parameters(self):
         parameters = {
-            param: getattr(self, param) 
+            param: getattr(self, param)
             for param in self._parameters
         }
         return parameters
-    
+
     @parameters.setter
     def parameters(self, parameters):
         for param, value in parameters.items():
@@ -62,6 +62,7 @@ class TestPerformer(metaclass=StructMeta):
             if value is not None:
                 setattr(self, param, value)
 
+
 class TestHandler(CADETProcess.dynamicEvents.EventHandler):
     def __init__(self):
         self.performer = TestPerformer()
@@ -73,7 +74,7 @@ class TestHandler(CADETProcess.dynamicEvents.EventHandler):
 
         parameters['performer'] = self.performer.parameters
 
-        return Dict(parameters)        
+        return Dict(parameters)
 
     @parameters.setter
     def parameters(self, parameters):
@@ -90,55 +91,58 @@ class TestHandler(CADETProcess.dynamicEvents.EventHandler):
         parameters['performer'] = self.performer.section_dependent_parameters
         return parameters
 
+
 class Test_Events(unittest.TestCase):
 
     def __init__(self, methodName='runTest'):
         super().__init__(methodName)
-        
+
     def create_event_handler(self):
         event_handler = TestHandler()
-        
+
         event_handler.add_event('evt0', 'performer.param_1', 0, 0)
         event_handler.add_event('evt1', 'performer.param_1', 1, 0)
-        event_handler.add_event('evt2', 'performer.param_2', (2,1), 0)
-        event_handler.add_event('evt3', 'performer.param_2', (3,2), 0)
-        event_handler.add_event('evt4', 'performer.param_2', (3,3), 0)
+        event_handler.add_event('evt2', 'performer.param_2', (2, 1), 0)
+        event_handler.add_event('evt3', 'performer.param_2', (3, 2), 0)
+        event_handler.add_event('evt4', 'performer.param_2', (3, 3), 0)
+
+        return event_handler
 
-        return event_handler 
-    
     def test_adding_events(self):
         event_handler = self.create_event_handler()
 
         with self.assertRaises(CADETProcess.CADETProcessError):
             event_handler.add_event('wrong_path', 'performer.wrong', 1)
-            
+
         with self.assertRaises(CADETProcess.CADETProcessError):
-            event_handler.add_event('wrong_value', 'performer.param_1', 'wrong')
-            
+            event_handler.add_event(
+                'wrong_value', 'performer.param_1', 'wrong'
+            )
+
         with self.assertRaises(CADETProcess.CADETProcessError):
             event_handler.add_event('duplicate', 'performer.param_1', 1)
             event_handler.add_event('duplicate', 'performer.param_1', 1)
 
         with self.assertRaises(CADETProcess.CADETProcessError):
-            event_handler.add_event('not_sec_dependent', 'performer.param_3', 1)
+            event_handler.add_event(
+                'not_sec_dependent', 'performer.param_3', 1
+            )
 
-    
     def test_event_times(self):
         event_handler = self.create_event_handler()
-        
+
         self.assertEqual(event_handler.event_times, [0.0])
 
         event_handler.evt0.time = 1
         self.assertEqual(event_handler.event_times, [0.0, 1.0])
-        
+
         event_handler.cycle_time = 10
         event_handler.evt0.time = 11
         self.assertEqual(event_handler.event_times, [0.0, 1.0])
 
-        
     def test_dependenciies(self):
         event_handler = self.create_event_handler()
-        
+
         event_handler.add_event_dependency('evt1', 'evt0')
         self.assertEqual(event_handler.event_times, [0.0])
 
@@ -148,7 +152,7 @@ class Test_Events(unittest.TestCase):
         event_handler.add_event_dependency('evt2', 'evt1', 2)
         self.assertEqual(event_handler.event_times, [0.0, 1.0, 2.0])
 
-        event_handler.add_event_dependency('evt3', ['evt1', 'evt0'], [2,1])
+        event_handler.add_event_dependency('evt3', ['evt1', 'evt0'], [2, 1])
         self.assertEqual(event_handler.event_times, [0.0, 1.0, 2.0, 3.0])
 
         # Dependent event
@@ -162,19 +166,14 @@ class Test_Events(unittest.TestCase):
             event_handler.add_event_dependency('evt1', 'evt0')
         # factors not matching
         with self.assertRaises(CADETProcess.CADETProcessError):
-            event_handler.add_event_dependency('evt1', 'evt0', [1,1])
-    
+            event_handler.add_event_dependency('evt1', 'evt0', [1, 1])
+
     def test_section_states(self):
         pass
-        
-        
-    #     self.assertEqual(event_handler.event_times, [0.0])
 
-
-    
     def test_timelines(self):
         pass
-        
-        
+
+
 if __name__ == '__main__':
     unittest.main()
